@@ -2,6 +2,8 @@ package Test::Smoke::App::Options;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use Test::Smoke::App::AppOption;
 
 =head1 NAME
@@ -16,7 +18,7 @@ my $opt = 'Test::Smoke::App::AppOption';
 sub synctree_config { # synctree.pl
     return (
         main_options => [
-            syncer(),
+            sync_type(),
         ],
         general_options => [
             ddir(),
@@ -171,22 +173,23 @@ sub runsmoke_config { # runsmoke.pl
             outfile(),
             rptfile(),
             jsnfile(),
-            killtime(),
-            makeopt(),
-            testmake(),
-            defaultenv(),
             cfg(),
-            harnessonly(),
-            harness3opts(),
-            hasharness3(),
-            opt_continue(),
-            is56x(),
-            locale(),
+            defaultenv(),
             force_c_locale(),
+            harness3opts(),
+            harnessonly(),
+            hasharness3(),
+            is56x(),
+            is_vms(),
             is_win32(),
+            killtime(),
+            locale(),
+            makeopt(),
+            opt_continue(),
+            skip_tests(),
+            testmake(),
             w32cc(),
             w32make(),
-            is_vms(),
         ],
     );
 }
@@ -360,7 +363,7 @@ sub from {
 }
 
 sub fsync { # How to sync the mdir for Forest.
-    my $s = syncer();
+    my $s = sync_type();
     $s->name('fsync');
     return $s;
 }
@@ -778,9 +781,9 @@ sub sync {
     );
 }
 
-sub syncer {
+sub sync_type {
     return $opt->new(
-        name     => 'syncer',
+        name     => 'sync_type',
         option   => '=s',
         allow    => [qw/git rsync copy/],
         default  => 'git',
